-------------------------------------------------------------------
-- Desc:	 R5 (" ")
-------------------------------------------------------------------


-------------------------------------------------------------------
function sl_quest_can_activate_R5(params)

	local player1 = getRandomPlayer("sl_quest_R5_player_criterion_checker1")
	local player2 = getRandomPlayer("sl_quest_R5_player_criterion_checker2")
	
	if player1 == nil or player2 == nil then
		return false
	end
	
	if player1:getCities():getCapital():getPersons():getAgent(AT_AMBASSADOR, getMyPlayer()) ~= nil then
		return false
	end
	
	params:setInt("iPlayerId1", player1:getId())
	params:setInt("iPlayerId2", player2:getId())

	return true

end


-------------------------------------------------------------------
function sl_quest_activate_R5(params)
	
	local player1 = getPlayerById(params:getInt("iPlayerId1"))
	local player2 = getPlayerById(params:getInt("iPlayerId2"))
		
	params:setStringW("sTitle1", getPlayerTitleW(player1, true))
	params:setStringW("sTitle2", getPlayerTitleW(player2, true))
	params:setBool("bDidAbmassadorSend", false)

	addEventHandler("E_OnAmbassadorArrival",			"sl_quest_R5_handler_E_OnAmbassadorArrival")
	addEventHandler("E_OnPlayerDefeat",					"sl_quest_R5_handler_E_OnPlayerDefeat")
	addEventHandler("E_OnBreakWarUnion",				"sl_quest_R5_handler_E_OnBreakWarUnion")
	addEventHandler("E_OnMyPlayerSendAmbassadorInCity",	"sl_quest_R5_handler_E_OnMyPlayerSendAmbassadorInCity")

end


-------------------------------------------------------------------
function sl_quest_deactivate_R5(params)

	removeEventHandler("E_OnAmbassadorArrival",				"sl_quest_R5_handler_E_OnAmbassadorArrival")
	removeEventHandler("E_OnPlayerDefeat",					"sl_quest_R5_handler_E_OnPlayerDefeat")
	removeEventHandler("E_OnBreakWarUnion",					"sl_quest_R5_handler_E_OnBreakWarUnion")
	removeEventHandler("E_OnMyPlayerSendAmbassadorInCity",	"sl_quest_R5_handler_E_OnMyPlayerSendAmbassadorInCity")
	
end


-------------------------------------------------------------------
--      
-------------------------------------------------------------------
function sl_quest_R5_player_criterion_checker1(player)

	local myPlayerId = getMyPlayer():getId()

	return	isPlayerLive(player) and player:isPlayable() and
			player:getId() ~= myPlayerId and
			player:isAlly(myPlayerId)
end


-------------------------------------------------------------------
--    
-------------------------------------------------------------------
function sl_quest_R5_player_criterion_checker2(player)

	local myPlayerId = getMyPlayer():getId()

	return	player ~= nil and player:isPlayable() and
			player:getId() ~= myPlayerId and
			not player:isAlly(myPlayerId)
end


-------------------------------------------------------------------
function sl_quest_before_desc_show_R5(params)

	local player1 = getPlayerById(params:getInt("iPlayerId1"))
	local city = player1:getCities():getCapital()

	if city ~= nil then
	
		params:setInt("iCityId", city:getId())	
		params:setStringW("sCity", getCityNameW(city))
		params:setStringW("sZone", getZoneNameW(city))
		
	end
	
end


-------------------------------------------------------------------
function sl_quest_R5_handler_E_OnAmbassadorArrival(params)

	local questParams = getQuestParams("R5")
	local player1 = getPlayerById(questParams:getInt("iPlayerId1"))
	local cityId = params:getInt("iCityId")
	
	if player1:getCities():getCapital():getId() ~= cityId then
		return
	end
	
	local playerId = params:getInt("iPlayerId")

	--    		
	if	getMyPlayer():getId() == playerId then
		
		local agent = getAgent(params:getInt("iAgentId"))
		if isEntityLive(agent) then
			removeAgentFromCity(agent)
		end
		
		fulfilQuest("R5")
		return
		
	end
	
	--    
	if questParams:getInt("iPlayerId2") == playerId then
		failQuest("R5")
		return
	end

end


-------------------------------------------------------------------
function sl_quest_R5_handler_E_OnPlayerDefeat(params)

	local questParams = getQuestParams("R5")
	if params:getInt("iPlayerId") == questParams:getInt("iPlayerId1") then
		failQuest("R5")
	end

end


-------------------------------------------------------------------
function sl_quest_R5_handler_E_OnBreakWarUnion(params)

	local questParams = getQuestParams("R5")
	if params:getInt("iPlayerId1") == questParams:getInt("iPlayerId1") then
		failQuest("R5")
	end
	
end


-------------------------------------------------------------------
--            2  1
-------------------------------------------------------------------
function sl_quest_R5_handler_E_OnMyPlayerSendAmbassadorInCity(params)

	if not isQuestActive("R5") then
		return
	end

	if params:getInt("iPlayerId") ~= getMyPlayer():getId() then
		return
	end
	
	--    ?
	local questParams = getQuestParams("R5")
	if questParams:getBool("bDidAbmassadorSend") then
		return
	end
	
	local player1 = getPlayerById(questParams:getInt("iPlayerId1"))
	local cityId = params:getInt("iCityId")
	
	if player1:getCities():getCapital():getId() ~= cityId then
		return
	end
	
	local player2 = getPlayerById(questParams:getInt("iPlayerId2"))
	if player2 ~= nil then
		
		local city = player2:getCities():getCapital()
		local agent = createAgent(AT_AMBASSADOR, player2)
		if agent ~= nil and city ~= nil then
		
			agent:setPos(getValidRealPos(agent, city:getPos(), player2))
			player2:getAI():getDiplomacyAI():sendAgentToEmbassy(agent, player1)
			questParams:setBool("bDidAbmassadorSend", true)
			
		end
		
	end
	
end


-------------------------------------------------------------------
function sl_quest_bonus_R5(params)

	local myDiplomacy = getMyPlayer():getDiplomacy()
	local player = getPlayerById(params:getInt("iPlayerId1"))
	
	myDiplomacy:changeRelationValueLevel(player, 1)
	
	params:setStringW("sRelation", getReleationLevelW(myDiplomacy:getRelationValue(player), true))

end


-------------------------------------------------------------------
function sl_quest_penalty_R5(params)

	local myDiplomacy = getMyPlayer():getDiplomacy()
	local player1 = getPlayerById(params:getInt("iPlayerId1"))
	local player2 = getPlayerById(params:getInt("iPlayerId2"))
	
	myDiplomacy:breakWarUnion(player1)
	player1:getDiplomacy():changeRelationValueLevel(player2, 3)
	if not player1:isAlly(player2:getId()) then
		player1:getDiplomacy():makeWarUnion(player2)
	end
	
	params:setStringW("sRelation", getReleationLevelW(myDiplomacy:getRelationValue(player1), true))

end