-------------------------------------------------------------------
--  T4 (" ")
-------------------------------------------------------------------


-------------------------------------------------------------------
local PREV_QUEST_ID = "T3"
local QUEST_ID = "T4"
local NEXT_QUEST_ID = "T4_1"
local SKILL_ID = "GeneralsPatent"
-------------------------------------------------------------------


-------------------------------------------------------------------
function sl_quest_can_activate_T4(params)

	if not isQuestCompleted(PREV_QUEST_ID) then
		return false
	end

	local person = getPersonById(params:getInt("iPersonId"))
	params:setStringW("sPerson", getEntityNameW(person))
	sl_quest_blinkPersonSelectGUIBtn(person, params, "sPersonBtnName")
	
	--    
	local gold = person:getAbilities():getSkillCostGold(SKILL_ID);
	addResourceToPlayer(getMyPlayer(), RT_GOLD, gold)

	--      
	local myPlayer = getMyPlayer()
	local city = myPlayer:getCities():getCapital()
	local enemy = generatePerson("General", "Nomads", "Paganism")
	addPersonToPlayer(enemy, getPlayer("Bandit"))
	enemy:setPos(getValidRealPos(enemy, getRandomBorderPos(city), myPlayer))
	enemy:setAILocked(true)
	enemy:setVisibleForMyPlayer(true)
	addSquadsToEntity(enemy, "Militia1_Nomads", 1)
	addSquadsToEntity(enemy, "LightCavalry1_Nomads", 1)	
	params:setInt("iEnemyId", enemy:getId())
	
	params:setBool("isTask1Done", false)
	params:setBool("isTask2Done", false)
	
	params:setString("sSkillBtnName", "")

	addEventHandler("E_OnSkillActivate",		"sl_quest_T4_handler_E_OnSkillActivate")
	addEventHandler("E_OnBattleResultClose",	"sl_quest_T4_handler_E_OnBattleResultClose")
	addEventHandler("E_OnGuiPanelShow",			"sl_quest_T4_handler_E_OnGuiPanelShow")
	addEventHandler("E_OnGuiPanelHide",			"sl_quest_T4_handler_E_OnGuiPanelHide")

	return true
		
end


-------------------------------------------------------------------
function sl_quest_deactivate_T4(params)

	removeEventHandler("E_OnSkillActivate",		"sl_quest_T4_handler_E_OnSkillActivate")
	removeEventHandler("E_OnBattleResultClose",	"sl_quest_T4_handler_E_OnBattleResultClose")
	removeEventHandler("E_OnGuiPanelShow",		"sl_quest_T4_handler_E_OnGuiPanelShow")
	removeEventHandler("E_OnGuiPanelHide",		"sl_quest_T4_handler_E_OnGuiPanelHide")
	
	stopBlinkGuiElement(params:getString("sPersonBtnName"))
	stopBlinkGuiElement(params:getString("sSkillBtnName"))
	
	sl_quest_destroy_person(params:getInt("iEnemyId"))
	
end


-------------------------------------------------------------------
function sl_quest_penalty_T4(params)

	sl_quest_destroy_person(params:getInt("iEnemyId"))
	sl_quest_on_tutorial_quest_failure()
	runQuest(NEXT_QUEST_ID)
	
end


-------------------------------------------------------------------
function sl_quest_T4_handler_E_OnSkillActivate(params)

	local questParams = getQuestParams(QUEST_ID)
	
	if	params:getString("sSkillId") == SKILL_ID and
		params:getInt("iPersonId") == questParams:getInt("iPersonId") then
		
		stopBlinkGuiElement(questParams:getString("sPersonBtnName"))
		stopBlinkGuiElement(questParams:getString("sSkillBtnName"))
		questParams:setBool("isTask1Done", true)

		if questParams:getBool("isTask2Done") then
			nextTutorialQuest(QUEST_ID, NEXT_QUEST_ID)
		end
	end

end


-------------------------------------------------------------------
function sl_quest_T4_handler_E_OnBattleResultClose(params)

	local questParams = getQuestParams(QUEST_ID)
	local winner = getEntity(params:getInt("iWinnerType"), params:getInt("iWinnerId"))
	
	if	winner:getPlayer():getId() == getMyPlayer():getId() and
		params:getInt("iLoserType") == ET_PERSON and
		params:getInt("iLoserId") == questParams:getInt("iEnemyId") then
		
		questParams:setBool("isTask2Done", true)

		if questParams:getBool("isTask1Done") then
			nextTutorialQuest(QUEST_ID, NEXT_QUEST_ID)
		end		
		
	end
		
end


-------------------------------------------------------------------
function sl_quest_T4_handler_E_OnGuiPanelShow(params)

	local panelName = params:getString("Name")	
	
	--   
	if	panelName == "PersonPanel" then
	
		local questParams = getQuestParams(QUEST_ID)
		
		if	getSelectedPerson():getId() == questParams:getInt("iPersonId") and
			not questParams:getBool("isTask1Done") then
			
			sl_quest_blinkPersonSkillBtn(SKILL_ID, questParams, "sSkillBtnName")
		
		end
		
	end
	
end


-------------------------------------------------------------------
function sl_quest_T4_handler_E_OnGuiPanelHide(params)
	
	local panelName = params:getString("Name")	
	
	if panelName == "PersonPanel" then
		stopBlinkGuiElement(getQuestParams(QUEST_ID):getString("sSkillBtnName"))
	end
	
end

